@@ -26,7 +26,7 @@
 #'   To find the desired survey questions, use the all of us data dictionary,
 #'   survey codebook, athena, data browser, or the allofus R package modified
 #'   codebook which can be found here:
-#'   https://roux-ohdsi.github.io/allofus/articles/searchable_codebook.html For
+#'   https://roux-ohdsi.github.io/allofus/vignettes/searchable_codebook.html For
 #'   questions regarding an individual's health history or family health
 #'   history, the function requires the specific concept_id (or concept_code)
 #'   for individual in question, whether that is "self" or another relative.
@@ -184,7 +184,7 @@ aou_survey <- function(cohort = NULL,
     missing_qs <- questions[!questions %in% c(regular_survey_qs, health_survey_qs)]
     if (length(missing_qs) > 0) {
       cli::cli_abort(c(paste("Concept codes", paste(missing_qs, collapse = ", "), "not found in codebook."),
-        "i" = "Check spelling and confirm that concept codes appear in the codebook at {.url https://roux-ohdsi.github.io/allofus/articles/searchable_codebook.html}."
+        "i" = "Check spelling and confirm that concept codes appear in the codebook at {.url https://roux-ohdsi.github.io/allofus/vignettes/searchable_codebook.html}."
       ))
     }
 
@@ -205,7 +205,7 @@ aou_survey <- function(cohort = NULL,
       too_general <- regular_survey_qs[regular_survey_concept_ids %in% aou_health_history_long$concept_id_overall]
       cli::cli_abort(c(paste("Concept code(s) ", paste0(too_general, collapse = ", "), "is/are too general."),
         "i" = "Health history codes must refer to a specific condition and person pairing.",
-        "i" = "Look for a specific condition in the health history codebook at {.url https://roux-ohdsi.github.io/allofus/articles/searchable_codebook.html}."
+        "i" = "Look for a specific condition in the health history codebook at {.url https://roux-ohdsi.github.io/allofus/vignettes/searchable_codebook.html}."
       ))
     }
 
@@ -223,11 +223,11 @@ aou_survey <- function(cohort = NULL,
       if (length(too_general) > 0) {
         cli::cli_abort(c(paste("Concept ID(s) ", paste0(too_general, collapse = ", "), "is/are too general."),
           "i" = "Health history codes must refer to a specific condition and person pairing.",
-          "i" = "Look for a specific condition in the health history codebook at {.url https://roux-ohdsi.github.io/allofus/articles/searchable_codebook.html}."
+          "i" = "Look for a specific condition in the health history codebook at {.url https://roux-ohdsi.github.io/allofus/vignettes/searchable_codebook.html}."
         ))
       } else {
         cli::cli_abort(c(paste("Concept ids", paste(missing_qs, collapse = ", "), "not found in codebook."),
-          "i" = "Confirm that concept codes appear in the codebook at {.url https://roux-ohdsi.github.io/allofus/articles/searchable_codebook.html}."
+          "i" = "Confirm that concept codes appear in the codebook at {.url https://roux-ohdsi.github.io/allofus/vignettes/searchable_codebook.html}."
         ))
       }
     }
@@ -339,7 +339,7 @@ aou_survey <- function(cohort = NULL,
       if (length(osci_specific) == 0) {
         cli::cli_abort(c(paste("Concept id ", specific_concept_id, "is too general."),
           "i" = "Health history codes must refer to a specific condition and person pairing.",
-          "i" = "Look for a specific condition in the health history codebook at {.url https://roux-ohdsi.github.io/allofus/articles/searchable_codebook.html}."
+          "i" = "Look for a specific condition in the health history codebook at {.url https://roux-ohdsi.github.io/allofus/vignettes/searchable_codebook.html}."
         ))
       }
       if (length(osci_specific) == 1 & !is.na(osci_overall)) { # this is not the case if an infectious disease question
@@ -425,12 +425,26 @@ aou_survey <- function(cohort = NULL,
     if (isTRUE(clean_answers)) {
       tmp <- dplyr::mutate(tmp,
         value_source_value = dplyr::case_when(
-          CONTAINS_SUBSTR(.data$value_source_value, "cope_") ~ value_source_value,
-          CONTAINS_SUBSTR(.data$value_source_value, "SDOH_") ~ value_source_value,
-          !CONTAINS_SUBSTR(.data$value_source_value, "_") ~ value_source_value,
+          CONTAINS_SUBSTR(.data$value_source_value, "cope_") ~ .data$value_source_value,
+          CONTAINS_SUBSTR(.data$value_source_value, "SDOH_") ~ .data$value_source_value,
+          !CONTAINS_SUBSTR(.data$value_source_value, "_") ~ .data$value_source_value,
           TRUE ~ REGEXP_EXTRACT(.data$value_source_value, ".+_(.+_*.*)")
         )
       )
+      # need to only do this if there are values in questions that correspond to these
+      tmptbl = aou_create_temp_table(
+        allofus::aou_concept_codes %>%
+          dplyr::filter(
+            stringr::str_detect(.data$code, "SDOH|COPE")) %>%
+          dplyr::rename(
+                value_source_value = "code",
+                 better_answer = "answer"
+                )
+      )
+
+      tmp <- dplyr::left_join(tmp, tmptbl, by = "value_source_value") %>%
+        dplyr::mutate(value_source_value = ifelse(is.na(.data$better_answer), .data$value_source_value, .data$better_answer)) %>%
+        dplyr::select(-"better_answer")
     }
 
     # go wide
