@@ -17,7 +17,7 @@ test_that("aou_sql returns a dataframe when collect = TRUE", {
 
   query <- "SELECT * FROM `{CDR}.person` LIMIT 10"
   result <- aou_sql(query, collect = TRUE)
-  expect_is(result, "data.frame")
+  expect_s3_class(result, "data.frame")
 })
 
 
